from setuptools import setup

setup(
    name = 'd3m-primitive-and-type-interfaces',
    version = '0.1',
    scripts = ['primitive', 'type'],
    url='https://gitlab.datadrivendiscovery.org/oxford/d3m-primitive-and-type-interfaces',
    author='Frank Wood, Atilim Gunes Baydin, Tuan-Anh Le and William Harvey',
    author_email='willh@robots.ox.ac.uk',
)
